# Major digit of the proj so version
%global proj_somaj 12
%define _requires_exceptions devel\(libogdi31.*\)\\|devel\(libcfitsio.*\)\\|libgrass
%define major 20
%define libname %mklibname %{name} %{major}
%define libnamedev %mklibname %{name} -d
%define build_libgrass 0
%{?with_libgrass: %define build_libgrass 1}

%define ogdidir %{_includedir}
%define ogdidir %{_includedir}/ogdi

Name: gdal
Version: 2.3.2
Release: %mkrel 1
Summary: The Geospatial Data Abstraction Library (GDAL)
Group: Sciences/Geosciences
License: MIT
URL: http://www.gdal.org/
Source: http://download.osgeo.org/gdal/%{name}-%{version}.tar.xz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot
Patch11:         GDALmake.opt.in.patch
Patch12:         gdal-libproj.patch
BuildRequires: bash-completion
BuildRequires:	libpng-devel
BuildRequires:	zlib-devel
BuildRequires:	geotiff-devel >= 1.2.0
BuildRequires:	libpng-devel
BuildRequires:	%{_lib}gif-devel
BuildRequires:	%{_lib}poppler-devel
BuildRequires:	%{_lib}tiff-devel
BuildRequires:	postgresql9.6-devel
BuildRequires:	libjpeg-devel
BuildRequires:	proj-devel >= 4.9.3
BuildRequires:  doxygen
%if %{build_libgrass}
Requires:	grass >= 6.4.0
BuildRequires:	grass
%else
BuildConflicts:	%mklibname -d grass 5 0
%endif
BuildRequires:	libjasper-devel
BuildRequires:	libgeos-devel >= 2.2.3
BuildRequires:	netcdf-devel >= 3.6.2
BuildRequires:	ogdi-devel
BuildRequires:	cfitsio-devel
BuildRequires:	python-numpy-devel
BuildRequires:	python-setuptools
BuildRequires:	sqlite3-devel
BuildRequires:	librx-devel
BuildRequires:	unixODBC-devel
BuildRequires:  xerces-c-devel
BuildRequires:	hdf5-devel
BuildRequires:	swig
BuildRequires:  gd-devel
BuildRequires:  gcc-c++
BuildRequires:  lzma-devel
BuildRequires:  mysql-devel
BuildRequires:  php-devel
BuildRequires:  %{_lib}curl-devel
BuildRequires:  g2clib-devel
BuildRequires:  dos2unix
Requires:       gpsbabel
Requires:       libproj.so.%{proj_somaj}()


%description
The Geospatial Data Abstraction Library (GDAL) is a unifying
C/C++ API for accessing raster geospatial data, and currently
includes formats like GeoTIFF, Erdas Imagine, Arc/Info
Binary, CEOS, DTED, GXF, and SDTS. It is intended to provide
efficient access, suitable for use in viewer applications,
and also attempts to preserve coordinate systems and metadata.
Python, C, and C++ interfaces are available.

%package python
Summary: The Python bindings for the GDAL library
Group: Development/Python
Requires: %{libname}
%py_requires -d

%description python
The Python bindings for the GDAL library

%package -n %{libname}
Summary: Libraries required for the GDAL library
Group: System/Libraries
Provides: lib%{name} = %{version}
Obsoletes: %{_lib}gdal-static-devel

%description -n %{libname}
Libraries required for the GDAL library

%package -n %{libnamedev}
Summary: Development files for using the GDAL library
Group: Development/Libraries
Requires: %{libname}
Provides: lib%{name}-devel = %{version}
Provides: %{name}-devel = %{version}

%description -n %{libnamedev}
Development files for using the GDAL library

%prep
%setup -q -n %{name}-%{version}
%patch11 -p1
%patch12 -p1

# Fix mandir
sed -i "s|^mandir=.*|mandir='\${prefix}/share/man'|" configure

# Fix wrong encoding EOL
for F in frmt_twms_srtm.xml frmt_wms_bluemarble_s3_tms.xml frmt_wms_virtualearth.xml frmt_twms_Clementine.xml;do
  find . -name "${F}" -exec dos2unix {} \;
done


%build
autoreconf -fi

%configure2_5x \
        CPPFLAGS=-D_XOPEN_SOURCE=700 \
        LIBS=-lgrib2c \
	--disable-static \
	--datadir=%_datadir/gdal \
	--includedir=%_includedir/gdal \
        --with-dods-root=no \
        --with-ogdi=%{ogdidir} \
        --with-cfitsio=yes \
        --with-geotiff=yes   \
        --with-libtiff=yes   \
        --with-rename-internal-libtiff-symbols=yes \
        --with-rename-internal-libgeotiff-symbols=yes \
        --with-libz=%_prefix      \
        --with-netcdf=%_prefix    \
        --with-hdf5=%_prefix      \
        --with-geos               \
        --with-jasper             \
        --with-png                \
        --with-poppler            \
        --with-gif                \
        --with-jpeg               \
        --with-odbc               \
        --with-sqlite3            \
        --with-mysql              \
        --with-curl               \
        --with-curl               \
        --with-hdf5             \
        --with-python             \
        --without-php                \
        --with-xerces=%_prefix         \
        --with-xerces-lib='-lxerces-c' \
        --with-xerces-inc=%_includedir \
        %if %{build_libgrass}
    	    --with-grass=%_libdir/grass     \
        %endif
        --with-threads            \
        --with-liblzma=yes        \
        --without-bsb             \
        --disable-rpath

# regenerate where needed
for M in perl python;
do
  make %{?_smp_mflags} -C swig/${M} veryclean
  make %{?_smp_mflags} -C swig/${M} generate
done
make %{?_smp_mflags} VERBOSE=1 all docs man

%install
rm -Rf %buildroot
mkdir -p %{buildroot}/%py_platsitedir
export PYTHONPATH="%{buildroot}/%py_platsitedir"
export DESTDIR=%{buildroot}
unset PYTHONDONTWRITEBYTECODE
export INST_MAN=%{_mandir}
###makeinstall_std install-man
make %{?_smp_mflags} install install-man DESTDIR=%{buildroot} INST_MAN=%{_mandir}

find %{buildroot} -name '*.la' -delete
%multiarch_binaries %{buildroot}%{_bindir}/gdal-config

# avoid PACKAGE redefines
sed -i 's,\(#define PACKAGE_.*\),/* \1 */,' %{buildroot}%{_includedir}/gdal/cpl_config.h


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%clean
rm -rf %buildroot

%files
%defattr(-,root,root)
/usr/etc/bash_completion.d/gdal-bash-completion.sh
%{_datadir}/gdal/
%{_bindir}/*
%{_mandir}/man1/*
%exclude %{_bindir}/gdal-config
%exclude %{_bindir}/multiarch-*
%exclude %{multiarch_bindir}/gdal-config
%exclude %{_mandir}/man1/gdal-config.1.*
%doc NEWS VERSION

%files -n %{libnamedev}
%defattr(-,root,root)
%{_bindir}/%{name}-config
%{_mandir}/man1/gdal-config.1.*
%{_libdir}/*.so
%{_libdir}/pkgconfig/gdal.pc
%{_includedir}/*
%_docdir/*
%multiarch %{multiarch_bindir}/gdal-config

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/*.so.%{major}*

%files python
%defattr(-,root,root,-)
%py_platsitedir/*


%changelog
* Mon Nov 12 2018 sadrianomorselli <adrianomorselli> 2.3.2-1uplos2018
- update
